---
name: Fix bug
about: 'bug'
title: 'Fix a bug or issue'
labels: 'bug'
assignees: ''
---

<!-- Summarize in one line the bug being fixed in this PR -->

This PR will close: #  

#### Changes proposed in this pull request

-
-

#### Task list
- [] CI tests added or updated